@@ -14,8 +14,10 @@ class AttributeReleaseInline(admin.TabularInline):
     model = models.AttributeRelease
 
     def formfield_for_choice_field(self, db_field, request, **kwargs):
+        def choices(ctx):
+            return [('', _('None'))] + get_attribute_names(ctx)
         if db_field.name == 'attribute_name':
-            kwargs['choices'] = to_iter(get_attribute_names)({'user': None, 'request': None})
+            kwargs['choices'] = to_iter(choices)({'user': None, 'request': None})
         return super(AttributeReleaseInline, self).formfield_for_choice_field(db_field, request, **kwargs)
 
 class A2ClientAdmin(ClientAdmin):
