@@ -19,7 +19,7 @@ class AttributeRelease(models.Model):
     name = models.CharField(verbose_name=_('name'), max_length=64)
     attribute_name = models.CharField(max_length=64,
             verbose_name=_('attribute name'),
-            choices=(('', 'None'),))
+            choices=(('', _('None')),))
 
     class Meta:
         verbose_name = _('OAuth2 attribute release')
